@@ -7,7 +7,7 @@ rmsea_aux <- function( n.ik , pi.k , probs , eps=10^(-30) ){
 	# n.ik ... [ classes , items , categories , groups ]	
 	# N.ik ... [ classes , items , categories]	
 	N.ik <- n.ik[,,,1]
-	G <- base::dim(n.ik)[4]
+	G <- dim(n.ik)[4]
 	pitot <- pi.k[,1]
 	eps <- 1E-10
 	if (G>1){ 
@@ -18,13 +18,13 @@ rmsea_aux <- function( n.ik , pi.k , probs , eps=10^(-30) ){
 	}
 
 	#*** extract maximum number of categories
-	maxK <- base::apply( N.ik , base::c(2,3) , base::sum , na.rm=TRUE )
-	maxK <- base::rowSums( maxK > eps )
+	maxK <- apply( N.ik , c(2,3) , sum , na.rm=TRUE )
+	maxK <- rowSums( maxK > eps )
 	
 	# calculate summed counts
-	N.ik_tot <- base::array( 0 , dim=dim(N.ik) )
+	N.ik_tot <- array( 0 , dim=dim(N.ik) )
 	N.ik_tot[,,1] <- N.ik[,,1,drop=FALSE]
-	K <- base::dim(N.ik)[3]			
+	K <- dim(N.ik)[3]			
 	for (kk in 2:K){
 		N.ik_tot[,,1] <- N.ik_tot[,,1,drop=FALSE] + N.ik[,,kk,drop=FALSE] 
 	}
@@ -35,12 +35,12 @@ rmsea_aux <- function( n.ik , pi.k , probs , eps=10^(-30) ){
 	
 	# calculate itemwise statistics
 	p.ik_observed <- N.ik / ( N.ik_tot + eps )
-	p.ik_observed[ base::is.na( p.ik_observed ) ] <- 0
+	p.ik_observed[ is.na( p.ik_observed ) ] <- 0
 	# define class weights 
-	pi.k_tot <- base::array( 0 , dim= base::dim(p.ik_observed) )
+	pi.k_tot <- array( 0 , dim= dim(p.ik_observed) )
 	for (kk in 1:K){
-		pi.k_tot[,,kk] <- base::matrix( pitot , nrow= base::dim(pi.k_tot)[1] , 
-				ncol= base::dim(pi.k_tot)[2] , byrow=FALSE )
+		pi.k_tot[,,kk] <- matrix( pitot , nrow= dim(pi.k_tot)[1] , 
+				ncol= dim(pi.k_tot)[2] , byrow=FALSE )
 	}
 	# calculate statistics
 	dist.item <- pi.k_tot * ( p.ik_observed - probs )^2		
@@ -48,9 +48,9 @@ rmsea_aux <- function( n.ik , pi.k , probs , eps=10^(-30) ){
 	for (kk in 2:K){ 
 		h1 <- h1 + dist.item[,,kk] 
 	}
-	itemfit.rmsea <- base::sqrt( base::colSums( h1 ) / maxK )
-	base::return(itemfit.rmsea)
+	itemfit.rmsea <- sqrt( colSums( h1 ) / maxK )
+	return(itemfit.rmsea)
 }
 
 
-.rmsea.aux <- rmsea_aux
\ No newline at end of file
+.rmsea.aux <- rmsea_aux
