@@ -29,9 +29,9 @@ sim.gdina <- function( n , q.matrix , delta , link = "identity" ,
             l1.al <- paste( l1.al , alpha.ii[,vv] , sep="") 
                             }
         resp.ii <- patt.prob[ match( l1.al , l1.Aj ) ]
-        if ( link=="logit"){ resp.ii <- plogis( resp.ii ) }
+        if ( link=="logit"){ resp.ii <- stats::plogis( resp.ii ) }
         if ( link=="log"){ resp.ii <- exp( resp.ii ) }
-        dat[ , ii ] <- 1 * ( runif( n ) < resp.ii )
+        dat[ , ii ] <- 1 * ( stats::runif( n ) < resp.ii )
                 }    
     res <- list( "data" = dat , "alpha" = alpha , "q.matrix" = q.matrix ,
                         "delta" = delta , "Aj" = Aj , "Mj" = Mj , "link" = link )
